<!-- HTML for static distribution bundle build -->
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8">
    <title>Swagger UI</title>
	<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swagger-ui@3.43.0/dist/swagger-ui.min.css">
    <link rel="icon" type="image/png" href="./swagger_ui/favicon-32x32.png" sizes="32x32" />
    <link rel="icon" type="image/png" href="./swagger_ui/favicon-16x16.png" sizes="16x16" />
    <style>
      html
      {
        box-sizing: border-box;
        overflow: -moz-scrollbars-vertical;
        overflow-y: scroll;
      }

      *,
      *:before,
      *:after
      {
        box-sizing: inherit;
      }

      body
      {
        margin:0;
        background: #fafafa;
      }
    </style>
  </head>

  <body>
    <div id="swagger-ui"></div>
	<script src="https://cdn.jsdelivr.net/npm/swagger-ui-dist@3.43.0/swagger-ui-bundle.min.js"></script>
	<script src="https://cdn.jsdelivr.net/npm/swagger-ui-dist@3.43.0/swagger-ui-standalone-preset.min.js"></script>
    <script>
    window.onload = function() {

      // Build a system
      const ui = SwaggerUIBundle({
        url: "/openapi.yaml?"+(new Date()).valueOf(),
        dom_id: '#swagger-ui',
        deepLinking: true,
        presets: [
          SwaggerUIBundle.presets.apis,
          SwaggerUIStandalonePreset
        ],
        plugins: [
          SwaggerUIBundle.plugins.DownloadUrl
        ],
        layout: "StandaloneLayout"
      })

      window.ui = ui
    }
  </script>
  </body>
</html>
